from dataclasses import dataclass
from datetime import datetime
from rsa import PublicKey


@dataclass
class SavedKey:
    key: PublicKey
    expire: datetime
    verification_string: str = ''
    auth: bool = False



from .saved_key import SavedKey
from .keys_conv import short_key_to_full, get_short_rsa_key
from .config import cfg
from .ovtp_server import OvtpServer
from .main import run_server
from .add_auth_keys import add_auth_keys
